@@ -51,17 +51,22 @@ pbr.packaging.LocalBuildLatex
 """
 
     pbr_config = config.get('pbr', dict())
-    if (('single-version-externally-mananged' in pbr_config and
-            pbr_config['single-version-externally-mananged'] in
-            packaging.TRUE_VALUES) or 'manpages' in pbr_config):
+    use_egg = packaging.get_boolean_option(
+        pbr_config, 'use-egg', 'PBR_USE_EGG')
+    # We always want non-egg install unless explicitly requested
+    if 'manpages' in pbr_config or not use_egg:
         config['global']['commands'] = config['global']['commands'] + """
 pbr.packaging.DistutilsInstall
 """
 
-    #config['backwards_compat']['dependency_links'] = parse_dependency_links()
-    #config['backwards_compat']['include_package_data'] = True
-    #config['backwards_compat']['tests_require'] = parse_requirements(
-    #    ["test-requirements.txt", "tools/test-requires"])
+    backwards_compat = config.get('backwards_compat', dict())
+    backwards_compat['dependency_links'] = "\n".join(
+        packaging.parse_dependency_links())
+    backwards_compat['include_package_data'] = 'True'
+    backwards_compat['tests_require'] = "\n".join(
+        packaging.parse_requirements(
+            ["test-requirements.txt", "tools/test-requires"]))
+    config['backwards_compat'] = backwards_compat
 
     files = config.get('files', dict())
     package = files.get('packages', metadata['name']).strip()
